## Funding

The work on ``eqdsk`` has been funded as part of the ``bluemira`` funding by:

* The RCUK Energy Programme [Grant Number EP/I501045]

* The Euratom research and training programme 2019–2020+ [Grant Number 633053].

* KIT, which is a member of the Helmholtz Association. ``bluemira`` is developed under the FUSION program funding.

## Acknowledgements

We would like to thank:

* Dr B. Dudson (University of York) for sharing FreeGS with the wider community,
the EQDSK reader written within FreeGS inspired initial work here.

* Dr O. Sauter and Dr S. Yu. Medvedev for their paper on COCOS conventions,
without which this work would have taken much longer [doi: 10.1016/j.cpc.2012.09.010](https://dx.doi.org/10.1016/j.cpc.2012.09.010)
